@@ -3,10 +3,10 @@
 from trytond.pool import PoolMeta
 
 __all__ = ['PurchaseLine']
-__metaclass__ = PoolMeta
 
 
 class PurchaseLine:
+    __metaclass__ = PoolMeta
     __name__ = 'purchase.line'
 
     @classmethod
@@ -17,9 +17,8 @@ class PurchaseLine:
                     'an "Account Asset" on product "%s".'),
                 })
 
-    def get_invoice_line(self, invoice_type):
-        invoice_lines = super(PurchaseLine, self).get_invoice_line(
-            invoice_type)
+    def get_invoice_line(self):
+        invoice_lines = super(PurchaseLine, self).get_invoice_line()
         if (self.product
                 and self.product.type == 'assets'
                 and self.product.depreciable):
